import 'package:dropdown_search/dropdown_search.dart';
import 'package:flutter/material.dart';
import 'package:hx_components_flutter/hx_utils.dart';

class HxDropdownSearch<T> extends StatelessWidget {
  final String label;
  final String? hint;
  final List<T> items;
  final T? selectedItem;
  final Function(T?)? onChanged;
  final Future<List<T>> Function(String)? asyncItems;
  final Widget Function(BuildContext, T, bool)? itemBuilder;
  final bool enabled;

  const HxDropdownSearch({
    super.key,
    required this.items,
    required this.onChanged,
    required this.label,
    this.hint,
    this.selectedItem,
    this.itemBuilder,
    this.enabled = true,
  }) : asyncItems = null;

  HxDropdownSearch.async({
    super.key,
    required this.onChanged,
    required this.label,
    this.hint,
    required this.asyncItems,
    this.selectedItem,
    this.itemBuilder,
    this.enabled = true,
  }) : items = [];

  @override
  Widget build(BuildContext context) {
    return DropdownSearch<T>(
      enabled: enabled,
      asyncItems: asyncItems,
      selectedItem: selectedItem,
      popupProps: PopupProps.menu(
        itemBuilder: itemBuilder,
        title: Text(label),
        fit: FlexFit.loose,
        showSearchBox: true,
        searchFieldProps: const TextFieldProps(
          style: TextStyle(fontSize: 16),
          decoration: InputDecoration(
            suffixIcon: Icon(Icons.search),
            labelStyle: TextStyle(color: kcPrimaryColor),
            border: OutlineInputBorder(
              borderSide: BorderSide(color: kcPrimaryColor),
            ),
          ),
        ),
      ),
      items: items,
      dropdownDecoratorProps: DropDownDecoratorProps(
        baseStyle: const TextStyle(fontSize: 16),
        dropdownSearchDecoration: InputDecoration(
          labelText: label,
          hintText: hint,
          filled: true,
          fillColor: kcLightGrey,
          isDense: true,
        ),
      ),
      onChanged: onChanged,
    );
  }
}
